@@ -1,12 +1,15 @@
 package App::gh;
 use warnings;
 use strict;
-our $VERSION = '0.57';
+our $VERSION = '0.60';
 use App::gh::Config;
 use App::gh::API;
+use Net::GitHub;
 use Cwd;
 require App::gh::Git;
 
+my $GITHUB;
+
 sub config {
     return "App::gh::Config";
 }
@@ -19,6 +22,25 @@ sub git {
     return App::gh::Git->repository;
 }
 
+sub github { 
+    my $class = shift;
+    my $access_token = $class->config->github_access_token;
+    return $GITHUB ||= Net::GitHub->new( access_token => $access_token ) if $access_token;
+
+    my $github_id = $class->config->github_id;
+    my $github_password = $class->config->github_password;
+
+    die('Please configure your github.user') unless $github_id;
+    die('Please configure your github.password') unless $github_password;
+
+    return $GITHUB ||= Net::GitHub->new(  # Net::GitHub::V3
+        login => $github_id,
+        pass  => $github_password,
+        # $class->config->github_token,
+    );
+}
+
+1;
 __END__
 
 =head1 NAME
