@@ -19,7 +19,7 @@ sub run {
     my ($self) = @_;
     my $local_repo = App::gh->git;
     my $remote = $self->{remote} || 'origin';
-    my $config = App::gh->config->current();
+    my $config = App::gh->config->current;
     my $basename = basename( $local_repo->wc_path() );
     my $reponame = $self->{name} || $basename;
     my $gh_id = App::gh->config->github_id();
@@ -29,37 +29,36 @@ sub run {
         croak "Remote [$remote] already exists. Try specifying another one using --remote.";
     }
 
+
     # Check if repo already exists
-    my $existing_gh_repo = eval { App::gh->api->repo_info( $gh_id, $reponame ) };
+    my $existing_gh_repo = eval { App::gh->github->repos->get( $gh_id, $reponame ) };
     if ($existing_gh_repo) {
-        # Update existing repo
-        my %args = (
-            description => ($self->{description}
-                                || $existing_gh_repo->{description} || ""),
-            homepage => ($self->{homepage}
-                             || $existing_gh_repo->{homepage} || "" ),
-            # Don't change visibility of existing repo
-            # public => $self->{private} ? 0 : 1 ,
-        );
-        my $ret = App::gh->api->repo_set_info( $gh_id, $reponame, %args );
-        print "Repository updated: \n";
-        App::gh::Utils->print_repo_info( $ret );
+        # FIXME: Update existing repo
+        # my %args = (
+        #     description => ($self->{description}
+        #                         || $existing_gh_repo->{description} || ""),
+        #     homepage => ($self->{homepage}
+        #                      || $existing_gh_repo->{homepage} || "" ),
+        #     # Don't change visibility of existing repo
+        #     # public => $self->{private} ? 0 : 1 ,
+        # );
+        # my $ret = App::gh->api->repo_set_info( $gh_id, $reponame, %args );
+        # print "Repository updated: \n";
     }
     else {
         # Create new repo
-        my %args = (
+        App::gh->github->repos->create({
+            # "org"  => "perlchina", ## the organization
             name => $reponame,
             description => ($self->{description} || ""),
             homepage => ($self->{homepage} || "" ),
             public => $self->{private} ? 0 : 1 ,
-        );
-        my $ret = App::gh->api->repo_create( %args );
-        print "Repository created: \n";
-        App::gh::Utils->print_repo_info( $ret );
+        });
+        print "Repository created. \n";
     }
 
     print "Adding GitHub repo $reponame as remote [$remote].\n";
-    $local_repo->command("remote", "add", "$remote",
+    $local_repo->command("remote", "add", $remote,
                          "git\@github.com:${gh_id}/${reponame}.git");
 
     # Only set up branch remote if it isn't already set up.
@@ -70,8 +69,7 @@ sub run {
     }
 
     print "Pushing to remote [$remote]\n";
-    $local_repo->command("push", "$remote", "master");
-
+    $local_repo->command("push", $remote , "master");
     print "Done.\n";
 }
 
